@@ -14,6 +14,7 @@ from typing import (
 )
 
 import dagster._check as check
+from dagster._annotations import public
 from dagster._core.decorator_utils import get_function_params
 from dagster._core.definitions.events import AssetKey
 from dagster._core.definitions.metadata import MetadataUserInput
@@ -21,7 +22,11 @@ from dagster._core.definitions.partition import PartitionsDefinition
 from dagster._core.definitions.utils import DEFAULT_GROUP_NAME, validate_group_name
 from dagster._core.errors import DagsterInvalidInvocationError
 from dagster._utils import merge_dicts
-from dagster._utils.backcompat import ExperimentalWarning, deprecation_warning
+from dagster._utils.backcompat import (
+    ExperimentalWarning,
+    deprecation_warning,
+    experimental_arg_warning,
+)
 
 from .dependency import NodeHandle
 from .events import AssetKey, CoercibleToAssetKeyPrefix
@@ -73,6 +78,7 @@ class AssetsDefinition(ResourceAddable):
 
     def __init__(
         self,
+        *,
         keys_by_input_name: Mapping[str, AssetKey],
         keys_by_output_name: Mapping[str, AssetKey],
         node_def: NodeDefinition,
@@ -178,9 +184,11 @@ class AssetsDefinition(ResourceAddable):
 
         return solid_def(*args, **kwargs)
 
+    @public
     @staticmethod
     def from_graph(
         graph_def: "GraphDefinition",
+        *,
         keys_by_input_name: Optional[Mapping[str, AssetKey]] = None,
         keys_by_output_name: Optional[Mapping[str, AssetKey]] = None,
         key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
@@ -216,7 +224,7 @@ class AssetsDefinition(ResourceAddable):
             group_name (Optional[str]): A group name for the constructed asset. Assets without a
                 group name are assigned to a group called "default".
             resource_defs (Optional[Mapping[str, ResourceDefinition]]):
-                A mapping of resource keys to resource definitions. These resources
+                (Experimental) A mapping of resource keys to resource definitions. These resources
                 will be initialized during execution, and can be accessed from the
                 body of ops in the graph during execution.
             partition_mappings (Optional[Mapping[str, PartitionMapping]]): Defines how to map partition
@@ -230,22 +238,26 @@ class AssetsDefinition(ResourceAddable):
                 outputs, and values are dictionaries of metadata to be associated with the related
                 asset.
         """
+        if resource_defs is not None:
+            experimental_arg_warning("resource_defs", "AssetsDefinition.from_graph")
         return AssetsDefinition._from_node(
-            graph_def,
-            keys_by_input_name,
-            keys_by_output_name,
-            internal_asset_deps,
-            partitions_def,
-            group_name,
-            resource_defs,
-            partition_mappings,
-            metadata_by_output_name,
+            node_def=graph_def,
+            keys_by_input_name=keys_by_input_name,
+            keys_by_output_name=keys_by_output_name,
+            internal_asset_deps=internal_asset_deps,
+            partitions_def=partitions_def,
+            group_name=group_name,
+            resource_defs=resource_defs,
+            partition_mappings=partition_mappings,
+            metadata_by_output_name=metadata_by_output_name,
             key_prefix=key_prefix,
         )
 
+    @public
     @staticmethod
     def from_op(
         op_def: OpDefinition,
+        *,
         keys_by_input_name: Optional[Mapping[str, AssetKey]] = None,
         keys_by_output_name: Optional[Mapping[str, AssetKey]] = None,
         key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
@@ -291,12 +303,12 @@ class AssetsDefinition(ResourceAddable):
                 asset.
         """
         return AssetsDefinition._from_node(
-            op_def,
-            keys_by_input_name,
-            keys_by_output_name,
-            internal_asset_deps,
-            partitions_def,
-            group_name,
+            node_def=op_def,
+            keys_by_input_name=keys_by_input_name,
+            keys_by_output_name=keys_by_output_name,
+            internal_asset_deps=internal_asset_deps,
+            partitions_def=partitions_def,
+            group_name=group_name,
             partition_mappings=partition_mappings,
             metadata_by_output_name=metadata_by_output_name,
             key_prefix=key_prefix,
@@ -305,6 +317,7 @@ class AssetsDefinition(ResourceAddable):
     @staticmethod
     def _from_node(
         node_def: Union[OpDefinition, "GraphDefinition"],
+        *,
         keys_by_input_name: Optional[Mapping[str, AssetKey]] = None,
         keys_by_output_name: Optional[Mapping[str, AssetKey]] = None,
         internal_asset_deps: Optional[Mapping[str, Set[AssetKey]]] = None,
@@ -315,9 +328,7 @@ class AssetsDefinition(ResourceAddable):
         metadata_by_output_name: Optional[Mapping[str, MetadataUserInput]] = None,
         key_prefix: Optional[CoercibleToAssetKeyPrefix] = None,
     ) -> "AssetsDefinition":
-        from .graph_definition import GraphDefinition
-
-        node_def = check.inst_param(node_def, "node_def", (GraphDefinition, OpDefinition))
+        node_def = check.inst_param(node_def, "node_def", NodeDefinition)
         keys_by_input_name = _infer_keys_by_input_names(
             node_def,
             check.opt_dict_param(
@@ -360,7 +371,7 @@ class AssetsDefinition(ResourceAddable):
         # For graph backed assets, we assign all assets to the same group_name, if specified.
         # To assign to different groups, use .with_prefix_or_groups.
         group_names_by_key = (
-            {asset_key: group_name for asset_key in keys_by_output_name.values()}
+            {asset_key: group_name for asset_key in keys_by_output_name_with_prefix.values()}
             if group_name
             else None
         )
@@ -391,14 +402,17 @@ class AssetsDefinition(ResourceAddable):
             else None,
         )
 
+    @public  # type: ignore
     @property
     def can_subset(self) -> bool:
         return self._can_subset
 
+    @public  # type: ignore
     @property
     def group_names_by_key(self) -> Mapping[AssetKey, str]:
         return self._group_names_by_key
 
+    @public  # type: ignore
     @property
     def op(self) -> OpDefinition:
         check.invariant(
@@ -407,10 +421,12 @@ class AssetsDefinition(ResourceAddable):
         )
         return cast(OpDefinition, self._node_def)
 
+    @public  # type: ignore
     @property
     def node_def(self) -> NodeDefinition:
         return self._node_def
 
+    @public  # type: ignore
     @property
     def asset_deps(self) -> Mapping[AssetKey, AbstractSet[AssetKey]]:
         return self._asset_deps
@@ -419,6 +435,7 @@ class AssetsDefinition(ResourceAddable):
     def input_names(self) -> Iterable[str]:
         return self.keys_by_input_name.keys()
 
+    @public  # type: ignore
     @property
     def key(self) -> AssetKey:
         check.invariant(
@@ -436,10 +453,12 @@ class AssetsDefinition(ResourceAddable):
         )
         return self.key
 
+    @public  # type: ignore
     @property
     def resource_defs(self) -> Dict[str, ResourceDefinition]:
         return dict(self._resource_defs)
 
+    @public  # type: ignore
     @property
     def keys(self) -> AbstractSet[AssetKey]:
         return self._selected_asset_keys
@@ -451,6 +470,7 @@ class AssetsDefinition(ResourceAddable):
         )
         return self.keys
 
+    @public  # type: ignore
     @property
     def dependency_keys(self) -> Iterable[AssetKey]:
         # the input asset keys that are directly upstream of a selected asset key
@@ -481,6 +501,7 @@ class AssetsDefinition(ResourceAddable):
             name: key for name, key in self.node_keys_by_input_name.items() if key in upstream_keys
         }
 
+    @public  # type: ignore
     @property
     def partitions_def(self) -> Optional[PartitionsDefinition]:
         return self._partitions_def
@@ -489,6 +510,7 @@ class AssetsDefinition(ResourceAddable):
     def metadata_by_key(self):
         return self._metadata_by_key
 
+    @public
     def get_partition_mapping(self, in_asset_key: AssetKey) -> PartitionMapping:
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=ExperimentalWarning)
@@ -627,6 +649,7 @@ class AssetsDefinition(ResourceAddable):
         for source_key, resource_def in self.resource_defs.items():
             yield from resource_def.get_resource_requirements(outer_context=source_key)
 
+    @public  # type: ignore
     @property
     def required_resource_keys(self) -> Set[str]:
         return {requirement.key for requirement in self.get_resource_requirements()}
