@@ -49,12 +49,11 @@ if TYPE_CHECKING:
 
 def schedule(
     cron_schedule: str,
-    pipeline_name: Optional[str] = None,
+    *,
+    job_name: Optional[str] = None,
     name: Optional[str] = None,
     tags: Optional[Dict[str, str]] = None,
     tags_fn: Optional[Callable[[ScheduleEvaluationContext], Optional[Dict[str, str]]]] = None,
-    solid_selection: Optional[List[str]] = None,
-    mode: Optional[str] = "default",
     should_execute: Optional[Callable[[ScheduleEvaluationContext], bool]] = None,
     environment_vars: Optional[Dict[str, str]] = None,
     execution_timezone: Optional[str] = None,
@@ -80,8 +79,6 @@ def schedule(
     Args:
         cron_schedule (str): A valid cron string specifying when the schedule will run, e.g.,
             ``'45 23 * * 6'`` for a schedule that runs at 11:45 PM every Saturday.
-        pipeline_name (Optional[str]): (legacy)  The name of the pipeline to execute when the
-            schedule runs.
         name (Optional[str]): The name of the schedule to create.
         tags (Optional[Dict[str, str]]): A dictionary of tags (string key-value pairs) to attach
             to the scheduled runs.
@@ -89,10 +86,6 @@ def schedule(
             that generates tags to attach to the schedules runs. Takes a
             :py:class:`~dagster.ScheduleEvaluationContext` and returns a dictionary of tags (string
             key-value pairs). You may set only one of ``tags`` and ``tags_fn``.
-        solid_selection (Optional[List[str]]): A list of solid subselection (including single
-            solid names) to execute when the schedule runs. e.g. ``['*some_solid+', 'other_solid']``
-        mode (Optional[str]): The pipeline mode in which to execute this schedule.
-            (Default: 'default')
         should_execute (Optional[Callable[[ScheduleEvaluationContext], bool]]): A function that runs at
             schedule execution time to determine whether a schedule should execute or skip. Takes a
             :py:class:`~dagster.ScheduleEvaluationContext` and returns a boolean (``True`` if the
@@ -176,9 +169,7 @@ def schedule(
         schedule_def = ScheduleDefinition(
             name=schedule_name,
             cron_schedule=cron_schedule,
-            pipeline_name=pipeline_name,
-            solid_selection=solid_selection,
-            mode=mode,
+            job_name=job_name,
             environment_vars=environment_vars,
             execution_timezone=execution_timezone,
             description=description,
@@ -196,6 +187,7 @@ def schedule(
 
 def monthly_schedule(
     pipeline_name: Optional[str],
+    *,
     start_date: datetime.datetime,
     name: Optional[str] = None,
     execution_day_of_month: int = 1,
@@ -357,6 +349,7 @@ def my_schedule_definition(_):
 
 def weekly_schedule(
     pipeline_name: Optional[str],
+    *,
     start_date: datetime.datetime,
     name: Optional[str] = None,
     execution_day_of_week: int = 0,
@@ -513,6 +506,7 @@ def my_schedule_definition(_):
 
 def daily_schedule(
     pipeline_name: Optional[str],
+    *,
     start_date: datetime.datetime,
     name: Optional[str] = None,
     execution_time: datetime.time = datetime.time(0, 0),
@@ -656,6 +650,7 @@ def my_schedule_definition(_):
 
 def hourly_schedule(
     pipeline_name: Optional[str],
+    *,
     start_date: datetime.datetime,
     name: Optional[str] = None,
     execution_time: datetime.time = datetime.time(0, 0),
