@@ -16,6 +16,7 @@ from typing import (
 )
 
 import dagster._check as check
+from dagster._annotations import public
 from dagster._config import Field, Shape
 from dagster._config.config_type import ConfigType
 from dagster._config.validate import validate_config
@@ -82,6 +83,7 @@ class JobDefinition(PipelineDefinition):
 
     def __init__(
         self,
+        *,
         graph_def: GraphDefinition,
         resource_defs: Optional[Mapping[str, ResourceDefinition]] = None,
         executor_def: Optional[ExecutorDefinition] = None,
@@ -171,21 +173,12 @@ class JobDefinition(PipelineDefinition):
         partitioned_config = None
 
         if partitions_def:
-            check.invariant(
-                not isinstance(config, ConfigMapping),
-                "Can't supply a ConfigMappi/ng for 'config' when 'partitions_def' is supplied.",
-            )
-
-            if isinstance(config, PartitionedConfig):
-                check.invariant(
-                    config.partitions_def == partitions_def,
-                    "Can't supply a PartitionedConfig for 'config' with a different "
-                    "PartitionsDefinition than supplied for 'partitions_def'.",
+            if isinstance(config, (ConfigMapping, PartitionedConfig)):
+                check.failed(
+                    "Can't supply a ConfigMapping or PartitionedConfig for 'config' when 'partitions_def' is supplied."
                 )
-                partitioned_config = config
-            else:
-                hardcoded_config = config if config else {}
-                partitioned_config = PartitionedConfig(partitions_def, lambda _: hardcoded_config)
+            hardcoded_config = config if config else {}
+            partitioned_config = PartitionedConfig(partitions_def, lambda _: hardcoded_config)
 
         if isinstance(config, ConfigMapping):
             config_mapping = config
@@ -256,26 +249,32 @@ class JobDefinition(PipelineDefinition):
     def describe_target(self):
         return f"{self.target_type} '{self.name}'"
 
+    @public  # type: ignore
     @property
     def executor_def(self) -> ExecutorDefinition:
         return self.get_mode_definition().executor_defs[0]
 
+    @public  # type: ignore
     @property
     def resource_defs(self) -> Mapping[str, ResourceDefinition]:
         return self.get_mode_definition().resource_defs
 
+    @public  # type: ignore
     @property
     def partitioned_config(self) -> Optional[PartitionedConfig]:
         return self.get_mode_definition().partitioned_config
 
+    @public  # type: ignore
     @property
     def config_mapping(self) -> Optional[ConfigMapping]:
         return self.get_mode_definition().config_mapping
 
+    @public  # type: ignore
     @property
     def loggers(self) -> Mapping[str, LoggerDefinition]:
         return self.get_mode_definition().loggers
 
+    @public
     def execute_in_process(
         self,
         run_config: Optional[Mapping[str, Any]] = None,
@@ -546,6 +545,7 @@ class JobDefinition(PipelineDefinition):
 
         return self._cached_partition_set
 
+    @public  # type: ignore
     @property
     def partitions_def(self) -> Optional[PartitionsDefinition]:
         mode = self.get_mode_definition()
@@ -554,6 +554,7 @@ class JobDefinition(PipelineDefinition):
 
         return mode.partitioned_config.partitions_def
 
+    @public
     def run_request_for_partition(
         self,
         partition_key: str,
@@ -574,6 +575,7 @@ class JobDefinition(PipelineDefinition):
 
         return RunRequest(run_key=run_key, run_config=run_config, tags=run_request_tags)
 
+    @public
     def with_hooks(self, hook_defs: AbstractSet[HookDefinition]) -> "JobDefinition":
         """Apply a set of hooks to all op instances within the job."""
 
