@@ -5,8 +5,8 @@ from typing import Any, Callable, List, NamedTuple, Optional, Sequence, Union, c
 import pendulum
 
 import dagster._check as check
+from dagster._annotations import PublicAttr
 from dagster._core.errors import (
-    DagsterInvalidDefinitionError,
     DagsterInvalidInvocationError,
     RunStatusSensorExecutionError,
     user_code_error_boundary,
@@ -82,10 +82,10 @@ class RunStatusSensorContext(
     NamedTuple(
         "_RunStatusSensorContext",
         [
-            ("sensor_name", str),
-            ("dagster_run", DagsterRun),
-            ("dagster_event", DagsterEvent),
-            ("instance", DagsterInstance),
+            ("sensor_name", PublicAttr[str]),
+            ("dagster_run", PublicAttr[DagsterRun]),
+            ("dagster_event", PublicAttr[DagsterEvent]),
+            ("instance", PublicAttr[DagsterInstance]),
         ],
     )
 ):
@@ -108,14 +108,6 @@ class RunStatusSensorContext(
             instance=check.inst_param(instance, "instance", DagsterInstance),
         )
 
-    def for_pipeline_failure(self):
-        return PipelineFailureSensorContext(
-            sensor_name=self.sensor_name,
-            dagster_run=self.dagster_run,
-            dagster_event=self.dagster_event,
-            instance=self.instance,
-        )
-
     def for_run_failure(self):
         """Converts RunStatusSensorContext to RunFailureSensorContext."""
         return RunFailureSensorContext(
@@ -134,26 +126,12 @@ class RunStatusSensorContext(
         return self.dagster_run
 
 
-class PipelineFailureSensorContext(RunStatusSensorContext):
-    """The ``context`` object available to a decorated function of ``pipeline_failure_sensor``.
-
-    Attributes:
-        sensor_name (str): the name of the sensor.
-        pipeline_run (PipelineRun): the failed pipeline run.
-        failure_event (DagsterEvent): the pipeline failure event.
-    """
-
-    @property
-    def failure_event(self):
-        return self.dagster_event
-
-
 class RunFailureSensorContext(RunStatusSensorContext):
     """The ``context`` object available to a decorated function of ``run_failure_sensor``.
 
     Attributes:
         sensor_name (str): the name of the sensor.
-        pipeline_run (PipelineRun): the failed pipeline run.
+        dagster_run (DagsterRun): the failed pipeline run.
         failure_event (DagsterEvent): the pipeline failure event.
     """
 
@@ -207,72 +185,6 @@ def build_run_status_sensor_context(
     )
 
 
-def pipeline_failure_sensor(
-    name: Optional[Union[Callable[..., Any], str]] = None,
-    minimum_interval_seconds: Optional[int] = None,
-    description: Optional[str] = None,
-    pipeline_selection: Optional[List[str]] = None,
-    monitored_pipelines: Optional[List[str]] = None,
-    default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
-) -> Callable[
-    [Callable[[PipelineFailureSensorContext], Union[SkipReason, PipelineRunReaction]]],
-    SensorDefinition,
-]:
-    """
-    Creates a sensor that reacts to pipeline failure events, where the decorated function will be
-    run when a pipeline run fails.
-
-    Takes a :py:class:`~dagster.PipelineFailureSensorContext`.
-
-    Args:
-        name (Optional[str]): The name of the pipeline failure sensor. Defaults to the name of the
-            decorated function.
-        minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
-            between sensor evaluations.
-        description (Optional[str]): A human-readable description of the sensor.
-        pipeline_selection (Optional[List[str]]): (deprecated in favor of monitored_pipelines)
-            Names of the pipelines that will be monitored by this failure sensor. Defaults to None,
-            which means the alert will be sent when any pipeline in the repository fails.
-        monitored_pipelines (Optional[List[str]]): Names of the pipelines that will be monitored by
-            this failure sensor. Defaults to None, which means the alert will be sent when any
-            pipeline in the repository fails.
-        default_status (DefaultSensorStatus): Whether the sensor starts as running or not. The default
-            status can be overridden from Dagit or via the GraphQL API.
-    """
-
-    def inner(
-        fn: Callable[[PipelineFailureSensorContext], Union[SkipReason, PipelineRunReaction]]
-    ) -> SensorDefinition:
-        check.callable_param(fn, "fn")
-        if name is None or callable(name):
-            sensor_name = fn.__name__
-        else:
-            sensor_name = name
-
-        if pipeline_selection:
-            deprecation_warning("pipeline_selection", "1.0.0", "Use monitored_pipelines instead.")
-        pipelines = monitored_pipelines if monitored_pipelines else pipeline_selection
-
-        @run_status_sensor(
-            run_status=DagsterRunStatus.FAILURE,
-            monitored_pipelines=pipelines,
-            name=sensor_name,
-            minimum_interval_seconds=minimum_interval_seconds,
-            description=description,
-            default_status=default_status,
-        )
-        def _pipeline_failure_sensor(context: RunStatusSensorContext):
-            return fn(context.for_pipeline_failure())
-
-        return _pipeline_failure_sensor
-
-    # This case is for when decorator is used bare, without arguments, i.e. @pipeline_failure_sensor
-    if callable(name):
-        return inner(name)
-
-    return inner
-
-
 def run_failure_sensor(
     name: Optional[Union[Callable[..., Any], str]] = None,
     minimum_interval_seconds: Optional[int] = None,
@@ -280,11 +192,9 @@ def run_failure_sensor(
     monitored_jobs: Optional[
         List[Union[PipelineDefinition, GraphDefinition, UnresolvedAssetJobDefinition]]
     ] = None,
-    monitored_pipelines: Optional[List[str]] = None,
     job_selection: Optional[
         List[Union[PipelineDefinition, GraphDefinition, UnresolvedAssetJobDefinition]]
     ] = None,
-    pipeline_selection: Optional[List[str]] = None,
     default_status: DefaultSensorStatus = DefaultSensorStatus.STOPPED,
     request_job: Optional[Union[GraphDefinition, JobDefinition]] = None,
     request_jobs: Optional[Sequence[Union[GraphDefinition, JobDefinition]]] = None,
@@ -307,15 +217,9 @@ def run_failure_sensor(
         monitored_jobs (Optional[List[Union[JobDefinition, GraphDefinition, UnresolvedAssetJobDefinition]]]): The jobs that
             will be monitored by this failure sensor. Defaults to None, which means the alert will
             be sent when any job in the repository fails.
-        monitored_pipelines (Optional[List[str]]): (legacy) Names of the pipelines that will be monitored by
-            this sensor. Defaults to None, which means the alert will be sent when any pipeline in
-            the repository fails.
         job_selection (Optional[List[Union[JobDefinition, GraphDefinition]]]): (deprecated in favor of monitored_jobs)
             The jobs that will be monitored by this failure sensor. Defaults to None, which means
             the alert will be sent when any job in the repository fails.
-        pipeline_selection (Optional[List[str]]): (legacy, deprecated in favor of monitored_pipelines)
-            Names of the pipelines that will be monitored by this sensor. Defaults to None, which
-            means the alert will be sent when any pipeline in the repository fails.
         default_status (DefaultSensorStatus): Whether the sensor starts as running or not. The default
             status can be overridden from Dagit or via the GraphQL API.
         request_job (Optional[Union[GraphDefinition, JobDefinition]]): The job a RunRequest should
@@ -333,12 +237,8 @@ def run_failure_sensor(
         else:
             sensor_name = name
 
-        if pipeline_selection:
-            deprecation_warning("pipeline_selection", "1.0.0", "Use monitored_pipelines instead.")
-        pipelines = monitored_pipelines if monitored_pipelines else pipeline_selection
-
         if job_selection:
-            deprecation_warning("job_selection", "1.0.0", "Use monitored_jobs instead.")
+            deprecation_warning("job_selection", "2.0.0", "Use monitored_jobs instead.")
         jobs = monitored_jobs if monitored_jobs else job_selection
 
         @run_status_sensor(
@@ -347,7 +247,6 @@ def run_failure_sensor(
             minimum_interval_seconds=minimum_interval_seconds,
             description=description,
             monitored_jobs=jobs,
-            monitored_pipelines=pipelines,
             default_status=default_status,
             request_job=request_job,
             request_jobs=request_jobs,
@@ -357,7 +256,7 @@ def run_failure_sensor(
 
         return _run_failure_sensor
 
-    # This case is for when decorator is used bare, without arguments, i.e. @pipeline_failure_sensor
+    # This case is for when decorator is used bare, without arguments
     if callable(name):
         return inner(name)
 
@@ -375,9 +274,6 @@ class RunStatusSensorDefinition(SensorDefinition):
             monitored by the sensor.
         run_status_sensor_fn (Callable[[RunStatusSensorContext], Union[SkipReason, PipelineRunReaction]]): The core
             evaluation function for the sensor. Takes a :py:class:`~dagster.RunStatusSensorContext`.
-        monitored_pipelines (Optional[List[str]]): (legacy) Names of the pipelines that will be monitored by
-            this sensor. Defaults to None, which means the alert will be sent when any pipeline in
-            the repository fails.
         minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
             between sensor evaluations.
         description (Optional[str]): A human-readable description of the sensor.
@@ -397,7 +293,6 @@ class RunStatusSensorDefinition(SensorDefinition):
         name: str,
         run_status: DagsterRunStatus,
         run_status_sensor_fn: Callable[[RunStatusSensorContext], RawSensorEvaluationFunctionReturn],
-        monitored_pipelines: Optional[List[str]] = None,
         minimum_interval_seconds: Optional[int] = None,
         description: Optional[str] = None,
         monitored_jobs: Optional[
@@ -413,7 +308,6 @@ class RunStatusSensorDefinition(SensorDefinition):
         check.str_param(name, "name")
         check.inst_param(run_status, "run_status", DagsterRunStatus)
         check.callable_param(run_status_sensor_fn, "run_status_sensor_fn")
-        check.opt_list_param(monitored_pipelines, "monitored_pipelines", str)
         check.opt_int_param(minimum_interval_seconds, "minimum_interval_seconds")
         check.opt_str_param(description, "description")
         check.opt_list_param(
@@ -507,9 +401,6 @@ class RunStatusSensorDefinition(SensorDefinition):
                     pipeline_run.external_pipeline_origin.external_repository_origin.repository_name
                     != context.repository_name
                     or
-                    # if pipeline is not selected
-                    (monitored_pipelines and pipeline_run.pipeline_name not in monitored_pipelines)
-                    or
                     # if job not selected
                     (
                         monitored_jobs
@@ -630,10 +521,7 @@ class RunStatusSensorDefinition(SensorDefinition):
 
 
 def run_status_sensor(
-    run_status: Optional[DagsterRunStatus] = None,
-    pipeline_run_status: Optional[DagsterRunStatus] = None,
-    monitored_pipelines: Optional[List[str]] = None,
-    pipeline_selection: Optional[List[str]] = None,
+    run_status: DagsterRunStatus,
     name: Optional[str] = None,
     minimum_interval_seconds: Optional[int] = None,
     description: Optional[str] = None,
@@ -657,16 +545,8 @@ def run_status_sensor(
     Takes a :py:class:`~dagster.RunStatusSensorContext`.
 
     Args:
-        run_status (Optional[DagsterRunStatus]): The status of run execution which will be
-            monitored by the sensor. One of run_status or pipeline_run_status must be provided
-        pipeline_run_status (Optional[DagsterRunStatus]): (deprecated in favor of run_status) The status of
-            pipeline execution which will be monitored by the sensor.
-        monitored_pipelines (Optional[List[str]]): Names of the pipelines that will be monitored by
-            this sensor. Defaults to None, which means the alert will be sent when any pipeline in
-            the repository fails.
-        pipeline_selection (Optional[List[str]]): (legacy; deprecated in favor of monitored_pipelines)
-            Names of the pipelines that will be monitored by this sensor. Defaults to None, which
-            means the alert will be sent when any pipeline in the repository fails.
+        run_status (DagsterRunStatus): The status of run execution which will be
+            monitored by the sensor.
         name (Optional[str]): The name of the sensor. Defaults to the name of the decorated function.
         minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
             between sensor evaluations.
@@ -692,28 +572,14 @@ def run_status_sensor(
         check.callable_param(fn, "fn")
         sensor_name = name or fn.__name__
 
-        if pipeline_run_status:
-            deprecation_warning("pipeline_run_status", "1.0.0", "Use run_status instead.")
-
-        run_status_final = run_status if run_status else pipeline_run_status
-        if not run_status_final:
-            raise DagsterInvalidDefinitionError(
-                "run_status must be provided to a run status sensor"
-            )
-
-        if pipeline_selection:
-            deprecation_warning("pipeline_selection", "1.0.0", "Use monitored_pipelines instead.")
-        pipelines = monitored_pipelines if monitored_pipelines else pipeline_selection
-
         if job_selection:
-            deprecation_warning("job_selection", "1.0.0", "Use monitored_jobs instead.")
+            deprecation_warning("job_selection", "2.0.0", "Use monitored_jobs instead.")
         jobs = monitored_jobs if monitored_jobs else job_selection
 
         return RunStatusSensorDefinition(
             name=sensor_name,
-            run_status=run_status_final,
+            run_status=run_status,
             run_status_sensor_fn=fn,
-            monitored_pipelines=pipelines,
             minimum_interval_seconds=minimum_interval_seconds,
             description=description,
             monitored_jobs=jobs,
