@@ -1,7 +1,7 @@
 from typing import Any, Dict, Optional, Union
 
 import dagster._check as check
-from dagster._core.definitions.pipeline_definition import PipelineDefinition
+from dagster._annotations import public
 from dagster._core.definitions.resource_definition import (
     IContainsGenerator,
     ResourceDefinition,
@@ -14,7 +14,9 @@ from dagster._core.storage.pipeline_run import PipelineRun
 
 
 class InitResourceContext:
-    """Resource-specific initialization context.
+    """The context object available as the argument to the initialization function of a :py:class:`dagster.ResourceDefinition`.
+
+    Users should not instantiate this object directly. To construct an `InitResourceContext` for testing purposes, use :py:func:`dagster.build_init_resource_context`.
 
     Attributes:
         resource_config (Any): The configuration data provided by the run config. The schema
@@ -32,6 +34,16 @@ class InitResourceContext:
         pipeline_run (Optional[PipelineRun]): (legacy) The dagster run to use. When initializing resources
             outside of execution context, this will be None.
 
+    Example:
+
+    .. code-block:: python
+
+        from dagster import resource, InitResourceContext
+
+        @resource
+        def the_resource(init_context: InitResourceContext):
+            init_context.log.info("Hello, world!")
+
     """
 
     def __init__(
@@ -41,65 +53,54 @@ class InitResourceContext:
         resource_def: Optional[ResourceDefinition] = None,
         instance: Optional[DagsterInstance] = None,
         dagster_run: Optional[PipelineRun] = None,
-        pipeline_run: Optional[PipelineRun] = None,
         log_manager: Optional[DagsterLogManager] = None,
-        pipeline_def_for_backwards_compat: Optional[PipelineDefinition] = None,
     ):
-
-        if dagster_run and pipeline_run:
-            raise DagsterInvariantViolationError(
-                "Provided both ``dagster_run`` and ``pipeline_run`` to InitResourceContext "
-                "initialization. Please provide one or the other."
-            )
         self._resource_config = resource_config
         self._resource_def = resource_def
         self._log_manager = log_manager
         self._instance = instance
         self._resources = resources
+        self._dagster_run = dagster_run
 
-        self._pipeline_def_for_backwards_compat = pipeline_def_for_backwards_compat
-        self._dagster_run = dagster_run or pipeline_run
-
+    @public  # type: ignore
     @property
     def resource_config(self) -> Any:
         return self._resource_config
 
+    @public  # type: ignore
     @property
     def resource_def(self) -> Optional[ResourceDefinition]:
         return self._resource_def
 
+    @public  # type: ignore
     @property
     def resources(self) -> Resources:
         return self._resources
 
+    @public  # type: ignore
     @property
     def instance(self) -> Optional[DagsterInstance]:
         return self._instance
 
-    @property
-    def pipeline_def_for_backwards_compat(self) -> Optional[PipelineDefinition]:
-        return self._pipeline_def_for_backwards_compat
-
     @property
     def dagster_run(self) -> Optional[PipelineRun]:
         return self._dagster_run
 
-    @property
-    def pipeline_run(self) -> Optional[PipelineRun]:
-        return self.dagster_run
-
+    @public  # type: ignore
     @property
     def log(self) -> Optional[DagsterLogManager]:
         return self._log_manager
 
     # backcompat: keep around this property from when InitResourceContext used to be a NamedTuple
+    @public  # type: ignore
     @property
     def log_manager(self) -> Optional[DagsterLogManager]:
         return self._log_manager
 
+    @public  # type: ignore
     @property
     def run_id(self) -> Optional[str]:
-        return self.pipeline_run.run_id if self.pipeline_run else None
+        return self.dagster_run.run_id if self.dagster_run else None
 
     def replace_config(self, config: Any) -> "InitResourceContext":
         return InitResourceContext(
@@ -107,7 +108,7 @@ class InitResourceContext:
             resources=self.resources,
             instance=self.instance,
             resource_def=self.resource_def,
-            pipeline_run=self.pipeline_run,
+            dagster_run=self.dagster_run,
             log_manager=self.log,
         )
 
@@ -160,9 +161,8 @@ class UnboundInitResourceContext(InitResourceContext):
             resources=resources,
             resource_def=None,
             instance=instance,
-            pipeline_run=None,
+            dagster_run=None,
             log_manager=initialize_console_manager(None),
-            pipeline_def_for_backwards_compat=None,
         )
 
     def __enter__(self):
@@ -204,10 +204,6 @@ class UnboundInitResourceContext(InitResourceContext):
     def instance(self) -> Optional[DagsterInstance]:
         return self._instance
 
-    @property
-    def pipeline_def_for_backwards_compat(self) -> Optional[PipelineDefinition]:
-        return None
-
     @property
     def pipeline_run(self) -> Optional[PipelineRun]:
         return None
