@@ -13,6 +13,7 @@ from typing import (
 )
 
 import dagster._check as check
+from dagster._annotations import public
 from dagster._core.definitions.asset_layer import AssetOutputInfo
 from dagster._core.definitions.events import (
     AssetKey,
@@ -24,7 +25,6 @@ from dagster._core.definitions.events import (
 )
 from dagster._core.definitions.metadata import RawMetadataValue
 from dagster._core.definitions.partition_key_range import PartitionKeyRange
-from dagster._core.definitions.solid_definition import SolidDefinition
 from dagster._core.definitions.time_window_partitions import TimeWindow
 from dagster._core.errors import DagsterInvariantViolationError
 from dagster._core.execution.plan.utils import build_resources_for_manager
@@ -45,6 +45,43 @@ RUN_ID_PLACEHOLDER = "__EPHEMERAL_RUN_ID"
 
 
 class OutputContext:
+    """
+    The context object that is available to the `handle_output` method of an :py:class:`IOManager`.
+
+    Users should not instantiate this object directly. To construct an
+    `OutputContext` for testing an IO Manager's `handle_output` method, use
+    :py:func:`dagster.build_output_context`.
+
+    Attributes:
+        step_key (Optional[str]): The step_key for the compute step that produced the output.
+        name (Optional[str]): The name of the output that produced the output.
+        run_id (Optional[str]): The id of the run that produced the output.
+        metadata (Optional[Mapping[str, RawMetadataValue]]): A dict of the metadata that is assigned to the
+            OutputDefinition that produced the output.
+        mapping_key (Optional[str]): The key that identifies a unique mapped output. None for regular outputs.
+        config (Optional[Any]): The configuration for the output.
+        dagster_type (Optional[DagsterType]): The type of this output.
+        log (Optional[DagsterLogManager]): The log manager to use for this output.
+        version (Optional[str]): (Experimental) The version of the output.
+        resource_config (Optional[Mapping[str, Any]]): The config associated with the resource that
+            initializes the RootInputManager.
+        resources (Optional[Resources]): The resources required by the output manager, specified by the
+            `required_resource_keys` parameter.
+        op_def (Optional[OpDefinition]): The definition of the op that produced the output.
+        asset_info: Optional[AssetOutputInfo]: (Experimental) Asset info corresponding to the
+            output.
+
+    Example:
+
+    .. code-block:: python
+
+        from dagster import IOManager, OutputContext
+
+        class MyIOManager(IOManager):
+            def handle_output(self, context: OutputContext, obj):
+                ...
+
+    """
 
     _step_key: Optional[str]
     _name: Optional[str]
@@ -53,7 +90,7 @@ class OutputContext:
     _metadata: Optional[Mapping[str, RawMetadataValue]]
     _mapping_key: Optional[str]
     _config: object
-    _solid_def: Optional["SolidDefinition"]
+    _op_def: Optional["OpDefinition"]
     _dagster_type: Optional["DagsterType"]
     _log: Optional["DagsterLogManager"]
     _version: Optional[str]
@@ -69,31 +106,6 @@ class OutputContext:
     _user_events: List[Union[AssetMaterialization, AssetObservation, Materialization]]
     _metadata_entries: Optional[Sequence[Union[MetadataEntry, PartitionMetadataEntry]]]
 
-    """
-    The context object that is available to the `handle_output` method of an :py:class:`IOManager`.
-
-    Attributes:
-        step_key (Optional[str]): The step_key for the compute step that produced the output.
-        name (Optional[str]): The name of the output that produced the output.
-        pipeline_name (Optional[str]): The name of the pipeline definition.
-        run_id (Optional[str]): The id of the run that produced the output.
-        metadata (Optional[Mapping[str, RawMetadataValue]]): A dict of the metadata that is assigned to the
-            OutputDefinition that produced the output.
-        mapping_key (Optional[str]): The key that identifies a unique mapped output. None for regular outputs.
-        config (Optional[Any]): The configuration for the output.
-        solid_def (Optional[SolidDefinition]): The definition of the solid that produced the output.
-        dagster_type (Optional[DagsterType]): The type of this output.
-        log (Optional[DagsterLogManager]): The log manager to use for this output.
-        version (Optional[str]): (Experimental) The version of the output.
-        resource_config (Optional[Mapping[str, Any]]): The config associated with the resource that
-            initializes the RootInputManager.
-        resources (Optional[Resources]): The resources required by the output manager, specified by the
-            `required_resource_keys` parameter.
-        op_def (Optional[OpDefinition]): The definition of the op that produced the output.
-        asset_info: Optional[AssetOutputInfo]: (Experimental) Asset info corresponding to the
-            output.
-    """
-
     def __init__(
         self,
         step_key: Optional[str] = None,
@@ -103,7 +115,6 @@ class OutputContext:
         metadata: Optional[Mapping[str, RawMetadataValue]] = None,
         mapping_key: Optional[str] = None,
         config: object = None,
-        solid_def: Optional["SolidDefinition"] = None,
         dagster_type: Optional["DagsterType"] = None,
         log_manager: Optional["DagsterLogManager"] = None,
         version: Optional[str] = None,
@@ -125,10 +136,7 @@ class OutputContext:
         self._metadata = metadata
         self._mapping_key = mapping_key
         self._config = config
-        check.invariant(
-            solid_def is None or op_def is None, "Can't provide both a solid_def and an op_def arg"
-        )
-        self._solid_def = solid_def or op_def
+        self._op_def = op_def
         self._dagster_type = dagster_type
         self._log = log_manager
         self._version = version
@@ -166,9 +174,15 @@ class OutputContext:
             self._resources_cm.__exit__(*exc)  # pylint: disable=no-member
 
     def __del__(self):
-        if self._resources_cm and self._resources_contain_cm and not self._cm_scope_entered:
+        if (
+            hasattr(self, "_resources_cm")
+            and self._resources_cm
+            and self._resources_contain_cm
+            and not self._cm_scope_entered
+        ):
             self._resources_cm.__exit__(None, None, None)  # pylint: disable=no-member
 
+    @public  # type: ignore
     @property
     def step_key(self) -> str:
         if self._step_key is None:
@@ -179,6 +193,7 @@ class OutputContext:
 
         return self._step_key
 
+    @public  # type: ignore
     @property
     def name(self) -> str:
         if self._name is None:
@@ -199,6 +214,7 @@ class OutputContext:
 
         return self._pipeline_name
 
+    @public  # type: ignore
     @property
     def run_id(self) -> str:
         if self._run_id is None:
@@ -209,40 +225,35 @@ class OutputContext:
 
         return self._run_id
 
+    @public  # type: ignore
     @property
     def metadata(self) -> Optional[Mapping[str, object]]:
         return self._metadata
 
+    @public  # type: ignore
     @property
     def mapping_key(self) -> Optional[str]:
         return self._mapping_key
 
+    @public  # type: ignore
     @property
     def config(self) -> Any:
         return self._config
 
-    @property
-    def solid_def(self) -> "SolidDefinition":
-        if self._solid_def is None:
-            raise DagsterInvariantViolationError(
-                "Attempting to access solid_def, "
-                "but it was not provided when constructing the OutputContext"
-            )
-
-        return self._solid_def
-
+    @public  # type: ignore
     @property
     def op_def(self) -> "OpDefinition":
         from dagster._core.definitions import OpDefinition
 
-        if self._solid_def is None:
+        if self._op_def is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access op_def, "
                 "but it was not provided when constructing the OutputContext"
             )
 
-        return cast(OpDefinition, self._solid_def)
+        return cast(OpDefinition, self._op_def)
 
+    @public  # type: ignore
     @property
     def dagster_type(self) -> "DagsterType":
         if self._dagster_type is None:
@@ -253,6 +264,7 @@ class OutputContext:
 
         return self._dagster_type
 
+    @public  # type: ignore
     @property
     def log(self) -> "DagsterLogManager":
         if self._log is None:
@@ -263,14 +275,17 @@ class OutputContext:
 
         return self._log
 
+    @public  # type: ignore
     @property
     def version(self) -> Optional[str]:
         return self._version
 
+    @public  # type: ignore
     @property
     def resource_config(self) -> Optional[Mapping[str, object]]:
         return self._resource_config
 
+    @public  # type: ignore
     @property
     def resources(self) -> Any:
         if self._resources is None:
@@ -291,10 +306,12 @@ class OutputContext:
     def asset_info(self) -> Optional[AssetOutputInfo]:
         return self._asset_info
 
+    @public  # type: ignore
     @property
     def has_asset_key(self) -> bool:
         return self._asset_info is not None
 
+    @public  # type: ignore
     @property
     def asset_key(self) -> AssetKey:
         if self._asset_info is None:
@@ -305,6 +322,7 @@ class OutputContext:
 
         return self._asset_info.key
 
+    @public  # type: ignore
     @property
     def asset_partitions_def(self) -> "PartitionsDefinition":
         """The PartitionsDefinition on the upstream asset corresponding to this input."""
@@ -335,6 +353,7 @@ class OutputContext:
 
         return self._step_context
 
+    @public  # type: ignore
     @property
     def has_partition_key(self) -> bool:
         """Whether the current run is a partitioned run"""
@@ -348,6 +367,7 @@ class OutputContext:
 
         return self._partition_key is not None
 
+    @public  # type: ignore
     @property
     def partition_key(self) -> str:
         """The partition key for the current run.
@@ -368,6 +388,7 @@ class OutputContext:
         )
         return cast(str, self._partition_key)
 
+    @public  # type: ignore
     @property
     def has_asset_partitions(self) -> bool:
         if self._warn_on_step_context_use:
@@ -383,6 +404,7 @@ class OutputContext:
         else:
             return False
 
+    @public  # type: ignore
     @property
     def asset_partition_key(self) -> str:
         """The partition key for output asset.
@@ -400,6 +422,7 @@ class OutputContext:
 
         return self.step_context.asset_partition_key_for_output(self.name)
 
+    @public  # type: ignore
     @property
     def asset_partition_key_range(self) -> PartitionKeyRange:
         """The partition key range for output asset.
@@ -416,6 +439,7 @@ class OutputContext:
 
         return self.step_context.asset_partition_key_range_for_output(self.name)
 
+    @public  # type: ignore
     @property
     def asset_partitions_time_window(self) -> TimeWindow:
         """The time window for the partitions of the output asset.
@@ -477,6 +501,7 @@ class OutputContext:
 
         return [run_id, step_key, name]
 
+    @public
     def get_identifier(self) -> Sequence[str]:
         """Utility method to get a collection of identifiers that as a whole represent a unique
         step output.
@@ -522,6 +547,7 @@ class OutputContext:
 
         return self.get_identifier()
 
+    @public
     def get_asset_identifier(self) -> Sequence[str]:
         if self.asset_key is not None:
             if self.has_asset_partitions:
@@ -539,6 +565,7 @@ class OutputContext:
 
         return self.get_asset_identifier()
 
+    @public
     def log_event(
         self, event: Union[AssetObservation, AssetMaterialization, Materialization]
     ) -> None:
@@ -617,6 +644,7 @@ class OutputContext:
 
         return self._user_events
 
+    @public
     def add_output_metadata(self, metadata: Mapping[str, RawMetadataValue]) -> None:
         """Add a dictionary of metadata to the handled output.
 
@@ -713,7 +741,7 @@ def get_output_context(
         metadata=output_def.metadata,
         mapping_key=step_output_handle.mapping_key,
         config=output_config,
-        solid_def=pipeline_def.get_solid(step.solid_handle).definition,
+        op_def=pipeline_def.get_solid(step.solid_handle).definition,
         dagster_type=output_def.dagster_type,
         log_manager=log_manager,
         version=version,
@@ -754,7 +782,6 @@ def build_output_context(
     version: Optional[str] = None,
     resource_config: Optional[Mapping[str, object]] = None,
     resources: Optional[Mapping[str, object]] = None,
-    solid_def: Optional[SolidDefinition] = None,
     op_def: Optional["OpDefinition"] = None,
     asset_key: Optional[Union[AssetKey, str]] = None,
     partition_key: Optional[str] = None,
@@ -780,7 +807,6 @@ def build_output_context(
         resources (Optional[Resources]): The resources to make available from the context.
             For a given key, you can provide either an actual instance of an object, or a resource
             definition.
-        solid_def (Optional[SolidDefinition]): The definition of the solid that produced the output.
         op_def (Optional[OpDefinition]): The definition of the op that produced the output.
         asset_key: Optional[Union[AssetKey, Sequence[str], str]]: The asset key corresponding to the
             output.
@@ -809,7 +835,6 @@ def build_output_context(
     version = check.opt_str_param(version, "version")
     resource_config = check.opt_dict_param(resource_config, "resource_config", key_type=str)
     resources = check.opt_dict_param(resources, "resources", key_type=str)
-    solid_def = check.opt_inst_param(solid_def, "solid_def", SolidDefinition)
     op_def = check.opt_inst_param(op_def, "op_def", OpDefinition)
     asset_key = AssetKey.from_coerceable(asset_key) if asset_key else None
     partition_key = check.opt_str_param(partition_key, "partition_key")
@@ -822,7 +847,6 @@ def build_output_context(
         metadata=metadata,
         mapping_key=mapping_key,
         config=config,
-        solid_def=solid_def,
         dagster_type=dagster_type,
         log_manager=initialize_console_manager(None),
         version=version,
